#
# spec file for package python-systemd
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-systemd
Version:        231
Release:        3.1
Summary:        Python wrappers for systemd functionality
License:        LGPL-2.1+
Group:          Development/Languages/Python
Url:            https://github.com/systemd/python-systemd
Source:         https://github.com/systemd/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRequires:  python-pytest
BuildRequires:  python-setuptools
BuildRequires:  systemd-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Python module for native access to the systemd facilities. Functionality is seperated into a number of modules:
* systemd.journal supports sending of structured messages to the journal and reading journal files,
* systemd.daemon wraps parts of libsystemd useful for writing daemons and socket activation,
* systemd.id128 provides functions for querying machine and boot identifiers and a lists of message identifiers provided by systemd,
* systemd.login wraps parts of libsystemd used to query logged in users and available seats and machines.

%prep
%setup -q

%build
make %{?_smp_mflags} build

%install
%make_install
%fdupes %{buildroot}/%{python_sitearch}

%check
# run doc-tests only when socket is available
test -f /run/systemd/journal/stdout || sed -i 's/--doctest[^ ]*//g' pytest.ini
make %{?_smp_mflags} check || :

%files
%defattr(-,root,root,-)
%doc LICENSE.txt README.md
%{python_sitearch}/*

%changelog
* Sat Oct 31 2015 jweberhofer@weberhofer.at
- Upgrade to release 231
  * Various build fixes and cleanups: documentation can be generated with 'make
    sphinx-html', pip install works out of the box.
  * Tests that cover most of the python code were added. As a result, a bug in
    sd_is_mq was fixed in systemd 227.
  * Functions sd_pid_notify and sd_pid_notify_with_fds are now wrapped as
    optional arguments to notify(), when compiled against a new-enough
    libsystemd.
- Run tests
- Removed obsolete python-systemd-libraries-for-opensuse-1310.patch patch
- New build dependencies had been added
* Thu Oct 22 2015 jweberhofer@weberhofer.at
- python-systemd-libraries-for-opensuse-1310.patch allows compilation
  on openSUSE 13.1
* Mon Oct 19 2015 jweberhofer@weberhofer.at
- Initial release 230
- This package is needed to resolve
  bnc#917818 - fail2ban can not use systemd-journal to ban ips
